#
# spec file for package python-exiv2
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-exiv2
Version:        0.17.3
Release:        1.1
Summary:        Python3 bindings for the exiv2 library
License:        GPL-3.0-only
Group:          Development/Languages/Python
URL:            https://github.com/jim-easterbrook/python-exiv2
Source:         https://github.com/jim-easterbrook/python-exiv2/archive/refs/tags/%{version}.tar.gz
# PATCH-FIX-UPSTREAM skip_network_tests.patch bsc#[0-9]+ mcepl@suse.com
# this patch makes things totally awesome
Patch0:         skip_network_tests.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libboost_python3-devel
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(exiv2)
%python_subpackages

%description
python3-exiv2 is a Python 3 binding to exiv2, the C++ library for manipulation
of EXIF, IPTC and XMP image metadata. It is a python 3 module that allows your
scripts to read and write metadata (EXIF, IPTC, XMP, thumbnails) embedded in
image files (JPEG, TIFF, ...).

It is designed as a high-level interface to the functionalities offered by
libexiv2. Using python’s built-in data types and standard modules, it provides
easy manipulation of image metadata.

%prep
%autosetup -p1

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
export NONET=1
%pyunittest_arch discover -v tests/

%files %{python_files}
%{python_sitearch}/exiv2
%{python_sitearch}/exiv2-%{version}*-info

%changelog
* Mon Feb 24 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.17.3
  * Binary wheels incorporate libexiv2 v0.28.5.
* Wed Feb 19 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.17.2
  * Binary wheels incorporate libexiv2 v0.28.4.
  * Fix TimeValue test when run with local negative UTC offset.
* Mon Nov 25 2024 Matej Cepl <mcepl@cepl.eu>
- Fix building
- Enable tests
- Add skip_network_tests.patch to mark network-requiring tests
  and skip them
* Sun Nov 24 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to 0.17.1:
  * Update README and INSTALL docs
  * Allow linux libdir name to be 'lib64' or 'lib'
  * Test localised exception with non-ASCII characters
- Updates from 0.17.0:
  * API change: derived classes of BasicIo are omitted from Python.
  * enableBMFF() function is deprecated.
  * Documentation is available on
    https://python-exiv2.readthedocs.io/
- Updates from 0.16.2:
  * Removed AnyError alias of Exiv2Error exception.
  * Metadatum.print() method is no longer renamed to _print.
  * Improved handling of enums:
  * Enum results are returned as Python enum instead of int.
  * Passing ints as enum parameters is deprecated.
  * Added dict-like behaviour to "data" structs.
  * Log handlers can be set/cleared from Python.
  * SWIG v4.1.0 or later required to run SWIG.
- Updates from 0.16.0:
  * Include native language support in Windows binary wheel builds.
  * API change: DateValue.getDate() returns Python dict.
  * API change: TimeValue.getTime() returns Python dict.
  * Deprecated: exiv2.Date and exiv2.Time objects.
  * Added buffer interface to PreviewImage
  * Set datum value from Python object directly instead of via
    string.
  * Moved Position enum to BasicIo class.
  * Moved CharsetId enum to CommentValue class.
  * Moved XmpArrayType and XmpStruct enums to XmpValue class.
  * Added enums for LogMsg.Level
  * More exiv2 structs are iterable for easy conversion to Python
    dict.
- Updates from 0.15.0:
  * Added __version_tuple__ for easy runtime version testing.
  * exiv2.testVersion() can be called from Python.
  * exiv2.DataBuf can be created from Python data.
  * Most data() methods return a Python memoryview.
  * exiv2.DataBuf and exiv2.BasicIo have writeable Python buffer
    interface.
* Wed Oct 11 2023 Ondřej Súkup <mimi.vx@gmail.com>
- fix files section
* Wed Oct 11 2023 Matej Cepl <mcepl@cepl.eu>
- Update to 0.14.1:
  - Added enums for XmpStruct and XmpArrayType
  - Added method for copy-free access to XmpTextValue raw data.
  - Fix occasional segfault with Image.io() of in-memory image
    data.
  - Add data() method to access Exiv2::StringValueBase raw bytes.
  - Enable video support in binary wheels.
  - Automatically cast Exiv2::Value return values to correct
    type.
  - Exiv2::byte* return values are converted to a simple buffer
    object.
  - Deprecated some superseded features. Use 'python -Wd' when
    testing.
  - Exiv2's Date & Time structs can be used from Python.
  - Removed Value.downCast methods deprecated in v0.7.0.
  - Reduced probability of segfaults by keeping references to
    other objects.
  - Fix iterator bug introduced in v0.10.0. (Issue #7.)
- Remove now superfluous py3exiv2-link-boost.patch
* Thu Oct  5 2023 Matej Cepl <mcepl@cepl.eu>
- Update to 0.12.0
  - Fix bug #2027823 (Compilation errors with exiv2-0.28)
- Remove the exiv2_0-28-0.patch patch again.
* Thu Aug 10 2023 Matej Cepl <mcepl@suse.com>
- Update to 0.12.3:
  - upstream doesn't release proper changelog
* Fri Aug  4 2023 Matej Cepl <mcepl@suse.com>
- Add exiv2_0-28-0.patch making the package compatible with the
  latest exiv2 0.28 (lp#2027823).
* Thu Oct 13 2022 Axel Braun <axel.braun@gmx.de>
- version 0.11.0
  no changelog
* Thu Jul  8 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.9.3
  * Add support for tag Xmp.mwg-rs.Regions/mwg-rs:
* Tue Oct 20 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.8.0
  * Add XmpSeq support
  * Add a datetime conversion to Python with iso format, update some unittests
- Added py3exiv2-link-boost.patch
* Tue Jul  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.1:
  * Various fixes to work with new exiv releases
* Mon Apr  8 2019 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.6.1
  * Add the streaming of the preview data
* Thu Jan 31 2019 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.5.0
  * Several fixes for exiv2-0.27
- Removed exiv2-1.0.27.patch (fixed upstream)
* Tue Jan 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to build with latest exiv2 releases:
  * exiv2-1.0.27.patch
* Thu Jun 28 2018 asn@cryptomilk.org
- Update to version 0.3.0
  * Add some convenient functions
* Sun May  6 2018 asn@cryptomilk.org
- Initial package
